==> 1.1.1.tar.gz: lib/src/mockup_controller.dart <==
import 'package:dotup_flutter_mockups/src/mockup_page_descriptor.dart';
import 'package:flutter/material.dart';

class MockupController extends ChangeNotifier {
  MockupController({
    required this.pages,
    required this.pageController,
  });

  final List<MockupPageDescriptor> pages;
  final PageController pageController;

  bool _pageMenuVisible = false;
  bool get pageMenuVisible => _pageMenuVisible;
  bool _pageInfosVisible = true;
  bool get pageInfosVisible => _pageInfosVisible;

  int _currentPage = -1;

  int get currentPageIndex => _currentPage;

  MockupPageDescriptor get currentPage => pages[_currentPage];

  WidgetBuilder getBuilder(int index) => pages[index].builder;

  void setCurrentIndex(int number) {
    if (number == _currentPage) {
      return;
    }
    _currentPage = number;
    _pageMenuVisible = false;

    // _pageInfosVisible = true;
    // notifyListeners();
  }

  Future<void> toNextPage() async {
    _currentPage += 1;
  }

  Future<void> toPage(int pageNumber) async {
    _currentPage = pageNumber;
    // pageController.animateToPage(pageNumber, duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    pageController.jumpToPage(pageNumber); //, duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    _pageMenuVisible = false;
    _pageInfosVisible = true;
    notifyListeners();
    // MockupPresenter.showPageInfo(this);
  }

  Future<void> toNamedPage(String title) async {}

  void showPageInfos() {
    _pageInfosVisible = true;
    notifyListeners();
  }

  void hidePageInfos() {
    _pageInfosVisible = false;
    notifyListeners();
  }

  void showPageMenu() {
    _pageMenuVisible = true;
    notifyListeners();
  }

  void hidePageMenu() {
    _pageMenuVisible = false;
    notifyListeners();
  }
}

==> 2.1.1.tar.gz: lib/src/mockup_controller.dart <==
import 'package:dotup_flutter_prototyping/dotup_flutter_prototyping.dart';
import 'package:flutter/material.dart';

import 'mockup_page_descriptor.dart';

class MockupController extends ChangeNotifier {
  MockupController({
    required this.descriptor,
    required this.pageController,
  });

  // final List<MockupDescriptor> pages;
  final PageController pageController;
  final MockupDescriptor descriptor;

  bool _pageMenuVisible = false;
  bool get pageMenuVisible => _pageMenuVisible;
  bool _pageInfosVisible = true;
  bool get pageInfosVisible => _pageInfosVisible;

  int _currentPage = -1;

  int get currentPageIndex => _currentPage;

  MockupPageDescriptor get currentPage => descriptor.pages[_currentPage];

  WidgetBuilder getBuilder(int index) => descriptor.pages[index].builder;

  void setCurrentIndex(int number) {
    if (number == _currentPage) {
      return;
    }
    _currentPage = number;
    _pageMenuVisible = false;

    // _pageInfosVisible = true;
    // notifyListeners();
  }

  Future<void> toNextPage() async {
    _currentPage += 1;
  }

  Future<void> toPage(int pageNumber) async {
    _currentPage = pageNumber;
    // pageController.animateToPage(pageNumber, duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    pageController.jumpToPage(pageNumber); //, duration: const Duration(milliseconds: 300), curve: Curves.easeIn);
    _pageMenuVisible = false;
    _pageInfosVisible = true;
    notifyListeners();
    // MockupPresenter.showPageInfo(this);
  }

  Future<void> toNamedPage(String title) async {}

  void showPageInfos() {
    _pageInfosVisible = true;
    notifyListeners();
  }

  void hidePageInfos() {
    _pageInfosVisible = false;
    notifyListeners();
  }

  void showPageMenu() {
    _pageMenuVisible = true;
    notifyListeners();
  }

  void hidePageMenu() {
    _pageMenuVisible = false;
    notifyListeners();
  }
}
